@@ -81,25 +81,25 @@ dimnames.svyimputationList<-function(x){
    c(dimnames(x$designs[[1]]),list(paste("imputation",1:length(x$designs))))
 }
 
-subset.svyimputationList<-function(x, subset,...,all=FALSE){
+subset.svyimputationList<-function(x, subset,...){
     n<-nrow(x$designs[[1]])
     e<-substitute(subset)
     r<-eval(e,x$designs[[1]]$variables, parent.frame())
-	same<-TRUE
-	for(i in 2:length(x$designs)){
-		r1<-eval(e,x$designs[[i]]$variables, parent.frame())
-		r1<-r1 & !is.na(r1)
-		if (any(r!=r1)) {
-			same<-FALSE
-			if (all) r <- r & r1 else r<- r | r1
-		   }
-		}
-	if (!same) warning('subset differed between imputations')
-	for(i in 1:length(x$designs)) 
-		x$designs[[i]]<-x$designs[[i]][r,]
-	x$call<-sys.call(-1)
-	x
-	}
+    x$designs[[1]]<-x$designs[[1]][r,]
+    same<-TRUE
+    for(i in 2:length(x$designs)){
+      r1<-eval(e,x$designs[[i]]$variables, parent.frame())
+      x$designs[[i]]<-x$designs[[i]][r1,]
+      r1<-r1 & !is.na(r1)
+      if (any(r!=r1)) {
+        same<-FALSE
+      }
+    }
+    if (!same) warning('subset differed between imputations')
+    
+    x$call<-sys.call(-1)
+    x
+  }
 
 subset.svyDBimputationList<-function(x, subset,...,all=FALSE){
     n<-nrow(x$designs[[1]])
